/*******************************************************************************
 * Copyright (c) 2007 Supelec.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This file is part of the ADLV tool
 * Version 1.0 (December 5, 2007)
 *
 * Contributors:
 *     Computer Science Department, Supelec : initial implementation
 * Contacts:
 *     Dominique.Marcadet@supelec.fr
 *     Frederic.Boulanger@supelec.fr
 *     Christophe.Jacquet@supelec.fr
 *******************************************************************************/
package fr.supelec.adlv.checker;

import java.util.ArrayList;
import java.util.List;

import fr.supelec.adlv.Component;
import fr.supelec.adlv.Port;

public class PortInstance {
	private final Port port;
	private final Component comp;

	private final static List<PortInstance> instances =
		new ArrayList<PortInstance>();

	private PortInstance(Port port, Component comp) {
		this.port = port;
		this.comp = comp;
	}

	public static PortInstance make(Port port, Component comp) {
		for(PortInstance pi : instances) {
			if(pi.port == port && pi.comp == comp) return pi;
		}
		PortInstance res = new PortInstance(port, comp);
		instances.add(res);
		return res;
	}

	public static PortInstance makeWithCurrent(Port port, Component comp, Component curComp) {
		if(comp == null &&
				curComp != null && curComp.getType() != null &&
				port.getComponent() == curComp.getType()) {

				comp = curComp;
		}
		return make(port, comp);
	}

	@Override
	public String toString() {
		return (comp == null ? "<app>" : comp.getName()) + "." + port.getName();
	}

	public Component getComponent() {
		return comp;
	}

	public Port getPort() {
		return port;
	}

/*	private boolean equals(PortInstance pi) {
		return port == pi.port && comp == pi.comp;
	}
	*/
}
