/*******************************************************************************
 * Copyright (c) 2007 Supelec.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This file is part of the ADLV tool
 * Version 1.0 (December 5, 2007)
 *
 * Contributors:
 *     Computer Science Department, Supelec : initial implementation
 * Contacts:
 *     Dominique.Marcadet@supelec.fr
 *     Frederic.Boulanger@supelec.fr
 *     Christophe.Jacquet@supelec.fr
 *******************************************************************************/
package fr.supelec.adlv.checker.generators;

import fr.supelec.adlv.checker.CheckingCodeGenerator;
import fr.supelec.adlv.checker.logic.Always;
import fr.supelec.adlv.checker.logic.And;
import fr.supelec.adlv.checker.logic.BackTo;
import fr.supelec.adlv.checker.logic.BinaryExpr;
import fr.supelec.adlv.checker.logic.Constant;
import fr.supelec.adlv.checker.logic.Expr;
import fr.supelec.adlv.checker.logic.Implies;
import fr.supelec.adlv.checker.logic.Interval;
import fr.supelec.adlv.checker.logic.Not;
import fr.supelec.adlv.checker.logic.Once;
import fr.supelec.adlv.checker.logic.Or;
import fr.supelec.adlv.checker.logic.Previous;
import fr.supelec.adlv.checker.logic.Since;
import fr.supelec.adlv.checker.logic.UnaryExpr;

public class DummyStringGenerator implements CheckingCodeGenerator {
	private String string = null;
	private String globalString = null;
	private int clauseNumber;

	public void generateNeverClause(Expr expr, String[] comments) {
		expr.accept(this);
		globalString += (clauseNumber++) + ") Never { " + string + " }\n";
	}

	public void start() {
		string = "";
		globalString = "";
		clauseNumber = 1;
	}

	public void stop() {
		System.out.println("Dummy string generation: ");
		System.out.println(globalString);
	}

	public void visit(Interval interval) {
		string = interval.toString();
	}

	private void visit(BinaryExpr operation, String operator) {
		operation.getA().accept(this);
		String sA = string;

		operation.getB().accept(this);
		String sB = string;

		string = "(" + sA + " " + operator + " " + sB + ")";
	}

	private void visit(UnaryExpr operation, String operator) {
		operation.getExpr().accept(this);
		string = operator + "(" + string + ")";
	}

	public void visit(And intersection) {
		visit(intersection, "/\\"); //∩");
	}

	public void visit(Or union) {
		visit(union, "\\/"); //∪");

	}

	public void visit(Not not) {
		visit(not, "NOT"); //¬");
	}

	public void visit(Since since) {
		visit(since, "SINCE");
	}

	public void visit(Previous previous) {
		visit(previous, "PREV");
	}

	public void visit(Always always) {
		visit(always, "[]");
	}

	public void visit(BackTo backTo) {
		visit(backTo, "BACKTO");
	}

	public void visit(Once once) {
		visit(once, "<>");
	}

	public void visit(Implies implies) {
		visit(implies, "=>"); //⇒");
	}

	public void visit(Constant constant) {
		string = constant.toString();
	}

	public String getName() {
		return "Dummy String Generator";
	}
}
