/*******************************************************************************
 * Copyright (c) 2007 Supelec.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This file is part of the ADLV tool
 * Version 1.0 (December 5, 2007)
 *
 * Contributors:
 *     Computer Science Department, Supelec : initial implementation
 * Contacts:
 *     Dominique.Marcadet@supelec.fr
 *     Frederic.Boulanger@supelec.fr
 *     Christophe.Jacquet@supelec.fr
 *******************************************************************************/
package fr.supelec.adlv.checker.logic;


public final class Always extends UnaryExpr {

	public Always(Expr expr) {
		super(expr);
	}

	@Override
	public void accept(ExprVisitor visitor) {
		visitor.visit(this);
	}

	@Override
	protected Expr develop(boolean cnf) {
		// don't develop temporal operators
		return this;
	}

	@Override
	public String toString() {
		return "[] " + expr;
	}

	@Override
	public UnaryExpr create(Expr a) {
		return new Always(a);
	}

	@Override
	public Expr simplify() {
		Expr sE = expr.simplify();
		if(TRUE.equals(sE)) return TRUE;
		if(FALSE.equals(sE)) return FALSE;
		return this;
	}

	@Override
	public boolean isTemporal() {
		return true;
	}

	@Override
	public ExprBundle getBundle() {
		ExprBundle eB = expr.getBundle();
		return new ExprBundle(
				eB.inner != null ? new Always(eB.inner) : null,
				eB.outer != null ? new Always(eB.outer) : null,
				eB.isBundled);
	}
}
