/*******************************************************************************
 * Copyright (c) 2007 Supelec.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This file is part of the ADLV tool
 * Version 1.0 (December 5, 2007)
 *
 * Contributors:
 *     Computer Science Department, Supelec : initial implementation
 * Contacts:
 *     Dominique.Marcadet@supelec.fr
 *     Frederic.Boulanger@supelec.fr
 *     Christophe.Jacquet@supelec.fr
 *******************************************************************************/
package fr.supelec.adlv.checker.logic;

import java.util.Set;

import fr.supelec.adlv.checker.PortInstance;

public class ComparisonPredicate extends Predicate {
	private final PortInstance port;
	private final String val;
	private final ComparisonOperator op;

	public ComparisonPredicate(PortInstance port, ComparisonOperator op, String val) {
		this.port = port;
		this.val = val;
		this.op = op;
	}


	@Override
	public boolean equals(Object o) {
		if(o instanceof ComparisonPredicate) {
			ComparisonPredicate oo = (ComparisonPredicate)o;
			return areConnectedOrEqual(port, oo.port) && (val.equals(oo.val));
		} else return false;
	}

	@Override
	public String toString() {
		return "(" + port + " " + op + " " + val + ")";
	}

	@Override
	public Predicate neg() {
		return new ComparisonPredicate(port, op.neg(), val);
	}

	@Override
	public boolean isNegationOf(Predicate p) {
		if(p instanceof ComparisonPredicate) {
			ComparisonPredicate cp = (ComparisonPredicate)p;
			return areConnectedOrEqual(cp.port, port) && cp.val.equals(val) && cp.op.neg() == op;
		}
		return false;
	}

	@Override
	public Set<PortInstance> getInputSignals() {
		return null; // not implemented for this class
	}
}
