/*******************************************************************************
 * Copyright (c) 2007 Supelec.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This file is part of the ADLV tool
 * Version 1.0 (December 5, 2007)
 *
 * Contributors:
 *     Computer Science Department, Supelec : initial implementation
 * Contacts:
 *     Dominique.Marcadet@supelec.fr
 *     Frederic.Boulanger@supelec.fr
 *     Christophe.Jacquet@supelec.fr
 *******************************************************************************/
package fr.supelec.adlv.checker.logic;

import java.util.Set;

import fr.supelec.adlv.checker.PortInstance;

public class SignalPredicate extends Predicate {
	private final boolean active;
	private final PortInstance signal;

	public SignalPredicate(boolean active, PortInstance signal) {
		this.active = active;
		this.signal = signal;
	}

	@Override
	public Predicate neg() {
		return new SignalPredicate(!active, signal);
	}

	@Override
	public boolean isNegationOf(Predicate p) {
		if(p instanceof SignalPredicate) {
			SignalPredicate sp = (SignalPredicate)p;
			return areConnectedOrEqual(sp.signal, signal) && sp.active != active;
		}
		return false;
	}

	@Override
	public String toString() {
		return (active ? "" : "!") + signal;
	}

	public PortInstance getSignal() {
		return signal;
	}

	public boolean isActive() {
		return active;
	}

	@Override
	public Set<PortInstance> getInputSignals() {
		return null; // not implemented for this class
	}
}
