/*******************************************************************************
 * Copyright (c) 2007 Supelec.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This file is part of the ADLV tool
 * Version 1.0 (December 5, 2007)
 *
 * Contributors:
 *     Computer Science Department, Supelec : initial implementation
 * Contacts:
 *     Dominique.Marcadet@supelec.fr
 *     Frederic.Boulanger@supelec.fr
 *     Christophe.Jacquet@supelec.fr
 *******************************************************************************/
package fr.supelec.adlv.parser;

import java.io.InputStream;

import antlr.ANTLRException;

public class EmfAdlvFeeder {

	public boolean parse( InputStream input ) {
		// Create parser/lexer
		lexer_ = new ADLVLexer( input );
		parser_ = new ADLVParser( lexer_ );
		parser_.setASTNodeClass(NumberedAST.class.getName());
		// Start parsing
		try {
			parser_.specification();
		}
		catch( ANTLRException ex ) {
			System.err.println( "ANTLRException during parsing : " + ex.getMessage() );
			return false;
		}

		if( parser_.errorNumber() > 0 ) {
			System.err.println( getErrors() );
			return false;
		}

		System.err.println( getWarnings() );
		return true;
	}

	public String getWarnings() {
		StringBuffer ret = new StringBuffer();

		String [] lwarnings = lexer_.warnings();
		for( int i = 0; i < lwarnings.length; ++i ) {
			ret.append( "Lexer warning: " );
			ret.append( lwarnings[i] );
			ret.append( '\n' );
		}

		String [] pwarnings = parser_.warnings();
		for( int i = 0; i < pwarnings.length; ++i ) {
			ret.append( "Parser warning: " );
			ret.append( pwarnings[i] );
			ret.append( '\n' );
		}

		return ret.toString();
	}

	public String getErrors() {
		StringBuffer ret = new StringBuffer();

		String [] lerrors = lexer_.errors();
		for( int i = 0; i < lerrors.length; ++i ) {
			ret.append( "Lexer error: " );
			ret.append( lerrors[i] );
			ret.append( '\n' );
		}

		String [] perrors = parser_.errors();
		for( int i = 0; i < perrors.length; ++i ) {
			ret.append( "Parser error: " );
			ret.append( perrors[i] );
			ret.append( '\n' );
		}

		return ret.toString();
	}

	public EmfAdlvHelper getHelper() {
		return parser_.getHelper();
	}

	private ADLVLexer lexer_;
	private ADLVParser parser_;
}
